AcCurrentCommand

Struct AcCurrentCommand 

pub struct AcCurrentCommand(/* private fields */);

Implementations

Source

impl AcCurrentCommand

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u16) -> Self

Convert from bits.

pub const fn into_bits(self) -> u16

Convert into bits.

pub const fn current_target_ac(&self) -> f32

This command sets the target motor AC current (peak, not RMS)

When the controller receives this message, it automatically switches to current control mode. This value must not be above the limits of the inverter and must be multiplied by 10 before sending. This is a signed parameter, and the sign represents the direction of the torque which correlates with the motor AC current. (For the correlation, please refer to the motor parameters)

Units: A

Bits: 0..16

pub const fn with_current_target_ac_checked( self, value: f32, ) -> Result<Self, ()>

This command sets the target motor AC current (peak, not RMS)

When the controller receives this message, it automatically switches to current control mode. This value must not be above the limits of the inverter and must be multiplied by 10 before sending. This is a signed parameter, and the sign represents the direction of the torque which correlates with the motor AC current. (For the correlation, please refer to the motor parameters)

Units: A

Bits: 0..16

pub const fn with_current_target_ac(self, value: f32) -> Self

This command sets the target motor AC current (peak, not RMS)

When the controller receives this message, it automatically switches to current control mode. This value must not be above the limits of the inverter and must be multiplied by 10 before sending. This is a signed parameter, and the sign represents the direction of the torque which correlates with the motor AC current. (For the correlation, please refer to the motor parameters)

Units: A

Bits: 0..16

pub const fn set_current_target_ac(&mut self, value: f32)

This command sets the target motor AC current (peak, not RMS)

When the controller receives this message, it automatically switches to current control mode. This value must not be above the limits of the inverter and must be multiplied by 10 before sending. This is a signed parameter, and the sign represents the direction of the torque which correlates with the motor AC current. (For the correlation, please refer to the motor parameters)

Units: A

Bits: 0..16

pub const fn set_current_target_ac_checked( &mut self, value: f32, ) -> Result<(), ()>

This command sets the target motor AC current (peak, not RMS)

When the controller receives this message, it automatically switches to current control mode. This value must not be above the limits of the inverter and must be multiplied by 10 before sending. This is a signed parameter, and the sign represents the direction of the torque which correlates with the motor AC current. (For the correlation, please refer to the motor parameters)

Units: A

Bits: 0..16

Source

impl AcCurrentCommand

pub fn try_with_current_target_ac(self, v: f32) -> Result<Self, OutOfRange>

Like Self::with_current_target_ac but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_current_target_ac(&mut self, v: f32) -> Result<(), OutOfRange>

Like Self::set_current_target_ac but returns OutOfRange instead of saturating an unrepresentable value.