BetaCellDataDebug

Struct BetaCellDataDebug 

pub struct BetaCellDataDebug(/* private fields */);

Implementations

Source

impl BetaCellDataDebug

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u64) -> Self

Convert from bits.

pub const fn into_bits(self) -> u64

Convert into bits.

pub const fn therm(&self) -> f32

Therm temperature

Units: C

Bits: 0..10

pub const fn with_therm_checked(self, value: f32) -> Result<Self, ()>

Therm temperature

Units: C

Bits: 0..10

pub const fn with_therm(self, value: f32) -> Self

Therm temperature

Units: C

Bits: 0..10

pub const fn set_therm(&mut self, value: f32)

Therm temperature

Units: C

Bits: 0..10

pub const fn set_therm_checked(&mut self, value: f32) -> Result<(), ()>

Therm temperature

Units: C

Bits: 0..10

pub const fn voltage_a(&self) -> f32

Cell voltage

Units: V

Bits: 10..23

pub const fn with_voltage_a_checked(self, value: f32) -> Result<Self, ()>

Cell voltage

Units: V

Bits: 10..23

pub const fn with_voltage_a(self, value: f32) -> Self

Cell voltage

Units: V

Bits: 10..23

pub const fn set_voltage_a(&mut self, value: f32)

Cell voltage

Units: V

Bits: 10..23

pub const fn set_voltage_a_checked(&mut self, value: f32) -> Result<(), ()>

Cell voltage

Units: V

Bits: 10..23

pub const fn voltage_b(&self) -> f32

Cell voltage

Units: V

Bits: 23..36

pub const fn with_voltage_b_checked(self, value: f32) -> Result<Self, ()>

Cell voltage

Units: V

Bits: 23..36

pub const fn with_voltage_b(self, value: f32) -> Self

Cell voltage

Units: V

Bits: 23..36

pub const fn set_voltage_b(&mut self, value: f32)

Cell voltage

Units: V

Bits: 23..36

pub const fn set_voltage_b_checked(&mut self, value: f32) -> Result<(), ()>

Cell voltage

Units: V

Bits: 23..36

pub const fn chip_id(&self) -> u8

Bits: 36..40

pub const fn with_chip_id_checked(self, value: u8) -> Result<Self, ()>

Bits: 36..40

pub const fn with_chip_id(self, value: u8) -> Self

Bits: 36..40

pub const fn set_chip_id(&mut self, value: u8)

Bits: 36..40

pub const fn set_chip_id_checked(&mut self, value: u8) -> Result<(), ()>

Bits: 36..40

pub const fn cell_a(&self) -> u8

Bits: 40..44

pub const fn with_cell_a_checked(self, value: u8) -> Result<Self, ()>

Bits: 40..44

pub const fn with_cell_a(self, value: u8) -> Self

Bits: 40..44

pub const fn set_cell_a(&mut self, value: u8)

Bits: 40..44

pub const fn set_cell_a_checked(&mut self, value: u8) -> Result<(), ()>

Bits: 40..44

pub const fn cell_b(&self) -> u8

Bits: 44..48

pub const fn with_cell_b_checked(self, value: u8) -> Result<Self, ()>

Bits: 44..48

pub const fn with_cell_b(self, value: u8) -> Self

Bits: 44..48

pub const fn set_cell_b(&mut self, value: u8)

Bits: 44..48

pub const fn set_cell_b_checked(&mut self, value: u8) -> Result<(), ()>

Bits: 44..48

pub const fn discharging_a(&self) -> bool

Whether cell is burning

Bits: 48..49

pub const fn with_discharging_a_checked(self, value: bool) -> Result<Self, ()>

Whether cell is burning

Bits: 48..49

pub const fn with_discharging_a(self, value: bool) -> Self

Whether cell is burning

Bits: 48..49

pub const fn set_discharging_a(&mut self, value: bool)

Whether cell is burning

Bits: 48..49

pub const fn set_discharging_a_checked(&mut self, value: bool) -> Result<(), ()>

Whether cell is burning

Bits: 48..49

pub const fn discharging_b(&self) -> bool

Whether cell is burning

Bits: 49..50

pub const fn with_discharging_b_checked(self, value: bool) -> Result<Self, ()>

Whether cell is burning

Bits: 49..50

pub const fn with_discharging_b(self, value: bool) -> Self

Whether cell is burning

Bits: 49..50

pub const fn set_discharging_b(&mut self, value: bool)

Whether cell is burning

Bits: 49..50

pub const fn set_discharging_b_checked(&mut self, value: bool) -> Result<(), ()>

Whether cell is burning

Bits: 49..50

pub const fn cvs_a(&self) -> bool

Whether C and S ADCs read too different

Bits: 50..51

pub const fn with_cvs_a_checked(self, value: bool) -> Result<Self, ()>

Whether C and S ADCs read too different

Bits: 50..51

pub const fn with_cvs_a(self, value: bool) -> Self

Whether C and S ADCs read too different

Bits: 50..51

pub const fn set_cvs_a(&mut self, value: bool)

Whether C and S ADCs read too different

Bits: 50..51

pub const fn set_cvs_a_checked(&mut self, value: bool) -> Result<(), ()>

Whether C and S ADCs read too different

Bits: 50..51

pub const fn cvs_b(&self) -> bool

Whether C and S ADCs read too different

Bits: 51..52

pub const fn with_cvs_b_checked(self, value: bool) -> Result<Self, ()>

Whether C and S ADCs read too different

Bits: 51..52

pub const fn with_cvs_b(self, value: bool) -> Self

Whether C and S ADCs read too different

Bits: 51..52

pub const fn set_cvs_b(&mut self, value: bool)

Whether C and S ADCs read too different

Bits: 51..52

pub const fn set_cvs_b_checked(&mut self, value: bool) -> Result<(), ()>

Whether C and S ADCs read too different

Bits: 51..52

pub const fn ow_a(&self) -> bool

Whether an open wire is detected on the cell

Bits: 52..53

pub const fn with_ow_a_checked(self, value: bool) -> Result<Self, ()>

Whether an open wire is detected on the cell

Bits: 52..53

pub const fn with_ow_a(self, value: bool) -> Self

Whether an open wire is detected on the cell

Bits: 52..53

pub const fn set_ow_a(&mut self, value: bool)

Whether an open wire is detected on the cell

Bits: 52..53

pub const fn set_ow_a_checked(&mut self, value: bool) -> Result<(), ()>

Whether an open wire is detected on the cell

Bits: 52..53

pub const fn ow_b(&self) -> bool

Whether an open wire is detected on the cell

Bits: 53..54

pub const fn with_ow_b_checked(self, value: bool) -> Result<Self, ()>

Whether an open wire is detected on the cell

Bits: 53..54

pub const fn with_ow_b(self, value: bool) -> Self

Whether an open wire is detected on the cell

Bits: 53..54

pub const fn set_ow_b(&mut self, value: bool)

Whether an open wire is detected on the cell

Bits: 53..54

pub const fn set_ow_b_checked(&mut self, value: bool) -> Result<(), ()>

Whether an open wire is detected on the cell

Bits: 53..54

Source

impl BetaCellDataDebug

pub fn try_with_therm(self, v: f32) -> Result<Self, OutOfRange>

Like Self::with_therm but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_therm(&mut self, v: f32) -> Result<(), OutOfRange>

Like Self::set_therm but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_with_voltage_a(self, v: f32) -> Result<Self, OutOfRange>

Like Self::with_voltage_a but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_voltage_a(&mut self, v: f32) -> Result<(), OutOfRange>

Like Self::set_voltage_a but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_with_voltage_b(self, v: f32) -> Result<Self, OutOfRange>

Like Self::with_voltage_b but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_voltage_b(&mut self, v: f32) -> Result<(), OutOfRange>

Like Self::set_voltage_b but returns OutOfRange instead of saturating an unrepresentable value.