pub struct BmsShutdownStatusAsReportedByVcu(/* private fields */);Implementations
Sourceimpl BmsShutdownStatusAsReportedByVcu
impl BmsShutdownStatusAsReportedByVcu
Sourcepub const fn bms_shutdown_as_reported_by_vcu(&self) -> u8
pub const fn bms_shutdown_as_reported_by_vcu(&self) -> u8
BMS Shutdown Status, as tracked and reported by VCU.
Bits: 0..8
Sourcepub const fn with_bms_shutdown_as_reported_by_vcu_checked(
self,
value: u8,
) -> Result<Self, ()>
pub const fn with_bms_shutdown_as_reported_by_vcu_checked( self, value: u8, ) -> Result<Self, ()>
BMS Shutdown Status, as tracked and reported by VCU.
Bits: 0..8
Sourcepub const fn with_bms_shutdown_as_reported_by_vcu(self, value: u8) -> Self
pub const fn with_bms_shutdown_as_reported_by_vcu(self, value: u8) -> Self
BMS Shutdown Status, as tracked and reported by VCU.
Bits: 0..8
Sourcepub const fn set_bms_shutdown_as_reported_by_vcu(&mut self, value: u8)
pub const fn set_bms_shutdown_as_reported_by_vcu(&mut self, value: u8)
BMS Shutdown Status, as tracked and reported by VCU.
Bits: 0..8