BrakeCurrentCommand

Struct BrakeCurrentCommand 

pub struct BrakeCurrentCommand(/* private fields */);

Implementations

Source

impl BrakeCurrentCommand

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u64) -> Self

Convert from bits.

pub const fn into_bits(self) -> u64

Convert into bits.

pub const fn brake_ac_current(&self) -> f32

Targets the brake current of the motor

It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.

Units: A

Bits: 0..16

pub const fn with_brake_ac_current_checked(self, value: f32) -> Result<Self, ()>

Targets the brake current of the motor

It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.

Units: A

Bits: 0..16

pub const fn with_brake_ac_current(self, value: f32) -> Self

Targets the brake current of the motor

It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.

Units: A

Bits: 0..16

pub const fn set_brake_ac_current(&mut self, value: f32)

Targets the brake current of the motor

It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.

Units: A

Bits: 0..16

pub const fn set_brake_ac_current_checked( &mut self, value: f32, ) -> Result<(), ()>

Targets the brake current of the motor

It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.

Units: A

Bits: 0..16

Source

impl BrakeCurrentCommand

pub fn try_with_brake_ac_current(self, v: f32) -> Result<Self, OutOfRange>

Like Self::with_brake_ac_current but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_brake_ac_current(&mut self, v: f32) -> Result<(), OutOfRange>

Like Self::set_brake_ac_current but returns OutOfRange instead of saturating an unrepresentable value.