FanbattEfuse

Struct FanbattEfuse 

pub struct FanbattEfuse(/* private fields */);

Implementations

Source

impl FanbattEfuse

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u64) -> Self

Convert from bits.

pub const fn into_bits(self) -> u64

Convert into bits.

pub const fn ADC(&self) -> u16

Raw ADC Value.

Ranges from 0 to 4095.

Bits: 0..16

pub const fn with_ADC_checked(self, value: u16) -> Result<Self, ()>

Raw ADC Value.

Ranges from 0 to 4095.

Bits: 0..16

pub const fn with_ADC(self, value: u16) -> Self

Raw ADC Value.

Ranges from 0 to 4095.

Bits: 0..16

pub const fn set_ADC(&mut self, value: u16)

Raw ADC Value.

Ranges from 0 to 4095.

Bits: 0..16

pub const fn set_ADC_checked(&mut self, value: u16) -> Result<(), ()>

Raw ADC Value.

Ranges from 0 to 4095.

Bits: 0..16

pub const fn voltage(&self) -> f32

Fanbatt eFuse Voltage

Units: V

Bits: 16..32

pub const fn with_voltage_checked(self, value: f32) -> Result<Self, ()>

Fanbatt eFuse Voltage

Units: V

Bits: 16..32

pub const fn with_voltage(self, value: f32) -> Self

Fanbatt eFuse Voltage

Units: V

Bits: 16..32

pub const fn set_voltage(&mut self, value: f32)

Fanbatt eFuse Voltage

Units: V

Bits: 16..32

pub const fn set_voltage_checked(&mut self, value: f32) -> Result<(), ()>

Fanbatt eFuse Voltage

Units: V

Bits: 16..32

pub const fn current(&self) -> f32

Fanbatt eFuse Current.

Units: A

Bits: 32..48

pub const fn with_current_checked(self, value: f32) -> Result<Self, ()>

Fanbatt eFuse Current.

Units: A

Bits: 32..48

pub const fn with_current(self, value: f32) -> Self

Fanbatt eFuse Current.

Units: A

Bits: 32..48

pub const fn set_current(&mut self, value: f32)

Fanbatt eFuse Current.

Units: A

Bits: 32..48

pub const fn set_current_checked(&mut self, value: f32) -> Result<(), ()>

Fanbatt eFuse Current.

Units: A

Bits: 32..48

pub const fn is_faulted(&self) -> u8

The state of the Fanbatt eFuse’s fault pin.

Bits: 48..52

pub const fn with_is_faulted_checked(self, value: u8) -> Result<Self, ()>

The state of the Fanbatt eFuse’s fault pin.

Bits: 48..52

pub const fn with_is_faulted(self, value: u8) -> Self

The state of the Fanbatt eFuse’s fault pin.

Bits: 48..52

pub const fn set_is_faulted(&mut self, value: u8)

The state of the Fanbatt eFuse’s fault pin.

Bits: 48..52

pub const fn set_is_faulted_checked(&mut self, value: u8) -> Result<(), ()>

The state of the Fanbatt eFuse’s fault pin.

Bits: 48..52

pub const fn is_enabled(&self) -> u8

The state of the Fanbatt eFuse’s Enable pin.

Bits: 52..56

pub const fn with_is_enabled_checked(self, value: u8) -> Result<Self, ()>

The state of the Fanbatt eFuse’s Enable pin.

Bits: 52..56

pub const fn with_is_enabled(self, value: u8) -> Self

The state of the Fanbatt eFuse’s Enable pin.

Bits: 52..56

pub const fn set_is_enabled(&mut self, value: u8)

The state of the Fanbatt eFuse’s Enable pin.

Bits: 52..56

pub const fn set_is_enabled_checked(&mut self, value: u8) -> Result<(), ()>

The state of the Fanbatt eFuse’s Enable pin.

Bits: 52..56

pub const fn control_state(&self) -> u8

The eFuse’s control state.

This is a car command originating from Calypso, but tracked by VCU. 0=ON, 1=AUTO, 2=OFF.

Bits: 56..64

pub const fn with_control_state_checked(self, value: u8) -> Result<Self, ()>

The eFuse’s control state.

This is a car command originating from Calypso, but tracked by VCU. 0=ON, 1=AUTO, 2=OFF.

Bits: 56..64

pub const fn with_control_state(self, value: u8) -> Self

The eFuse’s control state.

This is a car command originating from Calypso, but tracked by VCU. 0=ON, 1=AUTO, 2=OFF.

Bits: 56..64

pub const fn set_control_state(&mut self, value: u8)

The eFuse’s control state.

This is a car command originating from Calypso, but tracked by VCU. 0=ON, 1=AUTO, 2=OFF.

Bits: 56..64

pub const fn set_control_state_checked(&mut self, value: u8) -> Result<(), ()>

The eFuse’s control state.

This is a car command originating from Calypso, but tracked by VCU. 0=ON, 1=AUTO, 2=OFF.

Bits: 56..64

Source

impl FanbattEfuse

pub fn try_with_voltage(self, v: f32) -> Result<Self, OutOfRange>

Like Self::with_voltage but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_voltage(&mut self, v: f32) -> Result<(), OutOfRange>

Like Self::set_voltage but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_with_current(self, v: f32) -> Result<Self, OutOfRange>

Like Self::with_current but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_current(&mut self, v: f32) -> Result<(), OutOfRange>

Like Self::set_current but returns OutOfRange instead of saturating an unrepresentable value.