pub struct LightningPulseMessage(/* private fields */);Implementations
Sourceimpl LightningPulseMessage
impl LightningPulseMessage
Sourcepub const fn count(&self) -> u32
pub const fn count(&self) -> u32
Number of times the lightning pulse has been sent.
Bits: 0..32
Sourcepub const fn with_count_checked(self, value: u32) -> Result<Self, ()>
pub const fn with_count_checked(self, value: u32) -> Result<Self, ()>
Number of times the lightning pulse has been sent.
Bits: 0..32
Sourcepub const fn with_count(self, value: u32) -> Self
pub const fn with_count(self, value: u32) -> Self
Number of times the lightning pulse has been sent.
Bits: 0..32