pub struct MaxAcBrakeCurrentCommand(/* private fields */);Implementations
Sourceimpl MaxAcBrakeCurrentCommand
impl MaxAcBrakeCurrentCommand
Sourcepub const fn max_ac_brake_current_target(&self) -> f32
pub const fn max_ac_brake_current_target(&self) -> f32
This value sets the maximum allowable brake current on the AC side
This value must be multiplied by 10 before sending, only negative currents are accepted.
Units: A
Bits: 0..16
Sourcepub const fn with_max_ac_brake_current_target_checked(
self,
value: f32,
) -> Result<Self, ()>
pub const fn with_max_ac_brake_current_target_checked( self, value: f32, ) -> Result<Self, ()>
This value sets the maximum allowable brake current on the AC side
This value must be multiplied by 10 before sending, only negative currents are accepted.
Units: A
Bits: 0..16
Sourcepub const fn with_max_ac_brake_current_target(self, value: f32) -> Self
pub const fn with_max_ac_brake_current_target(self, value: f32) -> Self
This value sets the maximum allowable brake current on the AC side
This value must be multiplied by 10 before sending, only negative currents are accepted.
Units: A
Bits: 0..16
Sourcepub const fn set_max_ac_brake_current_target(&mut self, value: f32)
pub const fn set_max_ac_brake_current_target(&mut self, value: f32)
This value sets the maximum allowable brake current on the AC side
This value must be multiplied by 10 before sending, only negative currents are accepted.
Units: A
Bits: 0..16
Sourceimpl MaxAcBrakeCurrentCommand
impl MaxAcBrakeCurrentCommand
Sourcepub fn try_with_max_ac_brake_current_target(
self,
v: f32,
) -> Result<Self, OutOfRange>
pub fn try_with_max_ac_brake_current_target( self, v: f32, ) -> Result<Self, OutOfRange>
Like Self::with_max_ac_brake_current_target but returns
OutOfRange instead of saturating an unrepresentable value.
Sourcepub fn try_set_max_ac_brake_current_target(
&mut self,
v: f32,
) -> Result<(), OutOfRange>
pub fn try_set_max_ac_brake_current_target( &mut self, v: f32, ) -> Result<(), OutOfRange>
Like Self::set_max_ac_brake_current_target but returns
OutOfRange instead of saturating an unrepresentable value.