MaxAcCurrentCommand

Struct MaxAcCurrentCommand 

pub struct MaxAcCurrentCommand(/* private fields */);

Implementations

Source

impl MaxAcCurrentCommand

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u64) -> Self

Convert from bits.

pub const fn into_bits(self) -> u64

Convert into bits.

pub const fn max_current_ac_target(&self) -> f32

This value determines the maximum allowable drive current on the AC side

With this function you are able maximize the maximum torque on the motor. The value must be multiplied by 10 before sending

Units: A

Bits: 0..16

pub const fn with_max_current_ac_target_checked( self, value: f32, ) -> Result<Self, ()>

This value determines the maximum allowable drive current on the AC side

With this function you are able maximize the maximum torque on the motor. The value must be multiplied by 10 before sending

Units: A

Bits: 0..16

pub const fn with_max_current_ac_target(self, value: f32) -> Self

This value determines the maximum allowable drive current on the AC side

With this function you are able maximize the maximum torque on the motor. The value must be multiplied by 10 before sending

Units: A

Bits: 0..16

pub const fn set_max_current_ac_target(&mut self, value: f32)

This value determines the maximum allowable drive current on the AC side

With this function you are able maximize the maximum torque on the motor. The value must be multiplied by 10 before sending

Units: A

Bits: 0..16

pub const fn set_max_current_ac_target_checked( &mut self, value: f32, ) -> Result<(), ()>

This value determines the maximum allowable drive current on the AC side

With this function you are able maximize the maximum torque on the motor. The value must be multiplied by 10 before sending

Units: A

Bits: 0..16

Source

impl MaxAcCurrentCommand

pub fn try_with_max_current_ac_target(self, v: f32) -> Result<Self, OutOfRange>

Like Self::with_max_current_ac_target but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_max_current_ac_target( &mut self, v: f32, ) -> Result<(), OutOfRange>

Like Self::set_max_current_ac_target but returns OutOfRange instead of saturating an unrepresentable value.