MaxDcBrakeCurrentCommand

Struct MaxDcBrakeCurrentCommand 

pub struct MaxDcBrakeCurrentCommand(/* private fields */);

Implementations

Source

impl MaxDcBrakeCurrentCommand

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u16) -> Self

Convert from bits.

pub const fn into_bits(self) -> u16

Convert into bits.

pub const fn max_dc_brake_current_target(&self) -> f32

This value determines the maximum allowable brake current on the DC side

With this command the BMS can limit the maximum allowable battery charge current. The value has to be multiplied by 10 before sending. Only negative currents are accepted

Units: A

Bits: 0..16

pub const fn with_max_dc_brake_current_target_checked( self, value: f32, ) -> Result<Self, ()>

This value determines the maximum allowable brake current on the DC side

With this command the BMS can limit the maximum allowable battery charge current. The value has to be multiplied by 10 before sending. Only negative currents are accepted

Units: A

Bits: 0..16

pub const fn with_max_dc_brake_current_target(self, value: f32) -> Self

This value determines the maximum allowable brake current on the DC side

With this command the BMS can limit the maximum allowable battery charge current. The value has to be multiplied by 10 before sending. Only negative currents are accepted

Units: A

Bits: 0..16

pub const fn set_max_dc_brake_current_target(&mut self, value: f32)

This value determines the maximum allowable brake current on the DC side

With this command the BMS can limit the maximum allowable battery charge current. The value has to be multiplied by 10 before sending. Only negative currents are accepted

Units: A

Bits: 0..16

pub const fn set_max_dc_brake_current_target_checked( &mut self, value: f32, ) -> Result<(), ()>

This value determines the maximum allowable brake current on the DC side

With this command the BMS can limit the maximum allowable battery charge current. The value has to be multiplied by 10 before sending. Only negative currents are accepted

Units: A

Bits: 0..16

Source

impl MaxDcBrakeCurrentCommand

pub fn try_with_max_dc_brake_current_target( self, v: f32, ) -> Result<Self, OutOfRange>

Like Self::with_max_dc_brake_current_target but returns OutOfRange instead of saturating an unrepresentable value.

pub fn try_set_max_dc_brake_current_target( &mut self, v: f32, ) -> Result<(), OutOfRange>

Like Self::set_max_dc_brake_current_target but returns OutOfRange instead of saturating an unrepresentable value.