pub struct MaxDcCurrentCommand(/* private fields */);Implementations
Sourceimpl MaxDcCurrentCommand
impl MaxDcCurrentCommand
Sourcepub const fn max_dc_current_target(&self) -> f32
pub const fn max_dc_current_target(&self) -> f32
This value determines the maximum allowable drive current on the DC side
With this command the BMS can limit the maximum allowable battery discharge current. The value has to be multiplied by 10 before sending.
Units: A
Bits: 0..16
Sourcepub const fn with_max_dc_current_target_checked(
self,
value: f32,
) -> Result<Self, ()>
pub const fn with_max_dc_current_target_checked( self, value: f32, ) -> Result<Self, ()>
This value determines the maximum allowable drive current on the DC side
With this command the BMS can limit the maximum allowable battery discharge current. The value has to be multiplied by 10 before sending.
Units: A
Bits: 0..16
Sourcepub const fn with_max_dc_current_target(self, value: f32) -> Self
pub const fn with_max_dc_current_target(self, value: f32) -> Self
This value determines the maximum allowable drive current on the DC side
With this command the BMS can limit the maximum allowable battery discharge current. The value has to be multiplied by 10 before sending.
Units: A
Bits: 0..16
Sourcepub const fn set_max_dc_current_target(&mut self, value: f32)
pub const fn set_max_dc_current_target(&mut self, value: f32)
This value determines the maximum allowable drive current on the DC side
With this command the BMS can limit the maximum allowable battery discharge current. The value has to be multiplied by 10 before sending.
Units: A
Bits: 0..16
Sourcepub const fn set_max_dc_current_target_checked(
&mut self,
value: f32,
) -> Result<(), ()>
pub const fn set_max_dc_current_target_checked( &mut self, value: f32, ) -> Result<(), ()>
This value determines the maximum allowable drive current on the DC side
With this command the BMS can limit the maximum allowable battery discharge current. The value has to be multiplied by 10 before sending.
Units: A
Bits: 0..16
Sourceimpl MaxDcCurrentCommand
impl MaxDcCurrentCommand
Sourcepub fn try_with_max_dc_current_target(self, v: f32) -> Result<Self, OutOfRange>
pub fn try_with_max_dc_current_target(self, v: f32) -> Result<Self, OutOfRange>
Like Self::with_max_dc_current_target but returns
OutOfRange instead of saturating an unrepresentable value.
Sourcepub fn try_set_max_dc_current_target(
&mut self,
v: f32,
) -> Result<(), OutOfRange>
pub fn try_set_max_dc_current_target( &mut self, v: f32, ) -> Result<(), OutOfRange>
Like Self::set_max_dc_current_target but returns
OutOfRange instead of saturating an unrepresentable value.