pub struct BrakeCurrentCommand(/* private fields */);Implementations
Sourceimpl BrakeCurrentCommand
impl BrakeCurrentCommand
Sourcepub const fn brake_ac_current(&self) -> f32
pub const fn brake_ac_current(&self) -> f32
Targets the brake current of the motor
It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.
Units: A
Bits: 0..16
Sourcepub const fn with_brake_ac_current_checked(self, value: f32) -> Result<Self, ()>
pub const fn with_brake_ac_current_checked(self, value: f32) -> Result<Self, ()>
Targets the brake current of the motor
It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.
Units: A
Bits: 0..16
Sourcepub const fn with_brake_ac_current(self, value: f32) -> Self
pub const fn with_brake_ac_current(self, value: f32) -> Self
Targets the brake current of the motor
It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.
Units: A
Bits: 0..16
Sourcepub const fn set_brake_ac_current(&mut self, value: f32)
pub const fn set_brake_ac_current(&mut self, value: f32)
Targets the brake current of the motor
It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.
Units: A
Bits: 0..16
Sourcepub const fn set_brake_ac_current_checked(
&mut self,
value: f32,
) -> Result<(), ()>
pub const fn set_brake_ac_current_checked( &mut self, value: f32, ) -> Result<(), ()>
Targets the brake current of the motor
It will result negative torque relatively to the forward direction of the motor. This value must be multiplied by 10 before sending, only positive currents are accepted.
Units: A
Bits: 0..16
Sourceimpl BrakeCurrentCommand
impl BrakeCurrentCommand
Sourcepub fn try_with_brake_ac_current(self, v: f32) -> Result<Self, OutOfRange>
pub fn try_with_brake_ac_current(self, v: f32) -> Result<Self, OutOfRange>
Like Self::with_brake_ac_current but returns
OutOfRange instead of saturating an unrepresentable value.
Sourcepub fn try_set_brake_ac_current(&mut self, v: f32) -> Result<(), OutOfRange>
pub fn try_set_brake_ac_current(&mut self, v: f32) -> Result<(), OutOfRange>
Like Self::set_brake_ac_current but returns
OutOfRange instead of saturating an unrepresentable value.