pub struct Faults(/* private fields */);Implementations
Sourceimpl Faults
impl Faults
Sourcepub const fn CAN_OUTGOING_FAULT(&self) -> bool
pub const fn CAN_OUTGOING_FAULT(&self) -> bool
Bits: 0..1
Sourcepub const fn with_CAN_OUTGOING_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_CAN_OUTGOING_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 0..1
Sourcepub const fn with_CAN_OUTGOING_FAULT(self, value: bool) -> Self
pub const fn with_CAN_OUTGOING_FAULT(self, value: bool) -> Self
Bits: 0..1
Sourcepub const fn set_CAN_OUTGOING_FAULT(&mut self, value: bool)
pub const fn set_CAN_OUTGOING_FAULT(&mut self, value: bool)
Bits: 0..1
Sourcepub const fn set_CAN_OUTGOING_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_CAN_OUTGOING_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 0..1
Sourcepub const fn CAN_INCOMING_FAULT(&self) -> bool
pub const fn CAN_INCOMING_FAULT(&self) -> bool
Bits: 1..2
Sourcepub const fn with_CAN_INCOMING_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_CAN_INCOMING_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 1..2
Sourcepub const fn with_CAN_INCOMING_FAULT(self, value: bool) -> Self
pub const fn with_CAN_INCOMING_FAULT(self, value: bool) -> Self
Bits: 1..2
Sourcepub const fn set_CAN_INCOMING_FAULT(&mut self, value: bool)
pub const fn set_CAN_INCOMING_FAULT(&mut self, value: bool)
Bits: 1..2
Sourcepub const fn set_CAN_INCOMING_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_CAN_INCOMING_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 1..2
Sourcepub const fn BMS_CAN_MONITOR_FAULT(&self) -> bool
pub const fn BMS_CAN_MONITOR_FAULT(&self) -> bool
Bits: 2..3
Sourcepub const fn with_BMS_CAN_MONITOR_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_BMS_CAN_MONITOR_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 2..3
Sourcepub const fn with_BMS_CAN_MONITOR_FAULT(self, value: bool) -> Self
pub const fn with_BMS_CAN_MONITOR_FAULT(self, value: bool) -> Self
Bits: 2..3
Sourcepub const fn set_BMS_CAN_MONITOR_FAULT(&mut self, value: bool)
pub const fn set_BMS_CAN_MONITOR_FAULT(&mut self, value: bool)
Bits: 2..3
Sourcepub const fn set_BMS_CAN_MONITOR_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_BMS_CAN_MONITOR_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 2..3
Sourcepub const fn LIGHTNING_CAN_MONITOR_FAULT(&self) -> bool
pub const fn LIGHTNING_CAN_MONITOR_FAULT(&self) -> bool
Bits: 3..4
Sourcepub const fn with_LIGHTNING_CAN_MONITOR_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_LIGHTNING_CAN_MONITOR_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 3..4
Sourcepub const fn with_LIGHTNING_CAN_MONITOR_FAULT(self, value: bool) -> Self
pub const fn with_LIGHTNING_CAN_MONITOR_FAULT(self, value: bool) -> Self
Bits: 3..4
Sourcepub const fn set_LIGHTNING_CAN_MONITOR_FAULT(&mut self, value: bool)
pub const fn set_LIGHTNING_CAN_MONITOR_FAULT(&mut self, value: bool)
Bits: 3..4
Sourcepub const fn set_LIGHTNING_CAN_MONITOR_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_LIGHTNING_CAN_MONITOR_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 3..4
Sourcepub const fn ONBOARD_TEMP_FAULT(&self) -> bool
pub const fn ONBOARD_TEMP_FAULT(&self) -> bool
Bits: 4..5
Sourcepub const fn with_ONBOARD_TEMP_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_ONBOARD_TEMP_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 4..5
Sourcepub const fn with_ONBOARD_TEMP_FAULT(self, value: bool) -> Self
pub const fn with_ONBOARD_TEMP_FAULT(self, value: bool) -> Self
Bits: 4..5
Sourcepub const fn set_ONBOARD_TEMP_FAULT(&mut self, value: bool)
pub const fn set_ONBOARD_TEMP_FAULT(&mut self, value: bool)
Bits: 4..5
Sourcepub const fn set_ONBOARD_TEMP_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_ONBOARD_TEMP_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 4..5
Sourcepub const fn IMU_ACCEL_FAULT(&self) -> bool
pub const fn IMU_ACCEL_FAULT(&self) -> bool
Bits: 5..6
Sourcepub const fn with_IMU_ACCEL_FAULT_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_IMU_ACCEL_FAULT_checked(self, value: bool) -> Result<Self, ()>
Bits: 5..6
Sourcepub const fn with_IMU_ACCEL_FAULT(self, value: bool) -> Self
pub const fn with_IMU_ACCEL_FAULT(self, value: bool) -> Self
Bits: 5..6
Sourcepub const fn set_IMU_ACCEL_FAULT(&mut self, value: bool)
pub const fn set_IMU_ACCEL_FAULT(&mut self, value: bool)
Bits: 5..6
Sourcepub const fn set_IMU_ACCEL_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_IMU_ACCEL_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 5..6
Sourcepub const fn IMU_GYRO_FAULT(&self) -> bool
pub const fn IMU_GYRO_FAULT(&self) -> bool
Bits: 6..7
Sourcepub const fn with_IMU_GYRO_FAULT_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_IMU_GYRO_FAULT_checked(self, value: bool) -> Result<Self, ()>
Bits: 6..7
Sourcepub const fn with_IMU_GYRO_FAULT(self, value: bool) -> Self
pub const fn with_IMU_GYRO_FAULT(self, value: bool) -> Self
Bits: 6..7
Sourcepub const fn set_IMU_GYRO_FAULT(&mut self, value: bool)
pub const fn set_IMU_GYRO_FAULT(&mut self, value: bool)
Bits: 6..7
Sourcepub const fn set_IMU_GYRO_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_IMU_GYRO_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 6..7
Sourcepub const fn BSPD_PREFAULT(&self) -> bool
pub const fn BSPD_PREFAULT(&self) -> bool
Bits: 7..8
Sourcepub const fn with_BSPD_PREFAULT_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_BSPD_PREFAULT_checked(self, value: bool) -> Result<Self, ()>
Bits: 7..8
Sourcepub const fn with_BSPD_PREFAULT(self, value: bool) -> Self
pub const fn with_BSPD_PREFAULT(self, value: bool) -> Self
Bits: 7..8
Sourcepub const fn set_BSPD_PREFAULT(&mut self, value: bool)
pub const fn set_BSPD_PREFAULT(&mut self, value: bool)
Bits: 7..8
Sourcepub const fn ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT(&self) -> bool
pub const fn ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT(&self) -> bool
Bits: 8..9
Sourcepub const fn with_ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 8..9
Sourcepub const fn with_ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT(self, value: bool) -> Self
pub const fn with_ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT(self, value: bool) -> Self
Bits: 8..9
Sourcepub const fn set_ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT(&mut self, value: bool)
pub const fn set_ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT(&mut self, value: bool)
Bits: 8..9
Sourcepub const fn set_ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_ONBOARD_BRAKE_OPEN_CIRCUIT_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 8..9
Sourcepub const fn ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT(&self) -> bool
pub const fn ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT(&self) -> bool
Bits: 9..10
Sourcepub const fn with_ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 9..10
Sourcepub const fn with_ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT(self, value: bool) -> Self
pub const fn with_ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT(self, value: bool) -> Self
Bits: 9..10
Sourcepub const fn set_ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT(&mut self, value: bool)
pub const fn set_ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT(&mut self, value: bool)
Bits: 9..10
Sourcepub const fn set_ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_ONBOARD_ACCEL_OPEN_CIRCUIT_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 9..10
Sourcepub const fn ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT(&self) -> bool
pub const fn ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT(&self) -> bool
Bits: 10..11
Sourcepub const fn with_ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 10..11
Sourcepub const fn with_ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT(self, value: bool) -> Self
pub const fn with_ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT(self, value: bool) -> Self
Bits: 10..11
Sourcepub const fn set_ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT(&mut self, value: bool)
pub const fn set_ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT(&mut self, value: bool)
Bits: 10..11
Sourcepub const fn set_ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_ONBOARD_BRAKE_SHORT_CIRCUIT_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 10..11
Sourcepub const fn ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT(&self) -> bool
pub const fn ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT(&self) -> bool
Bits: 11..12
Sourcepub const fn with_ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 11..12
Sourcepub const fn with_ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT(self, value: bool) -> Self
pub const fn with_ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT(self, value: bool) -> Self
Bits: 11..12
Sourcepub const fn set_ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT(&mut self, value: bool)
pub const fn set_ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT(&mut self, value: bool)
Bits: 11..12
Sourcepub const fn set_ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_ONBOARD_ACCEL_SHORT_CIRCUIT_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 11..12
Sourcepub const fn ONBOARD_PEDAL_DIFFERENCE_FAULT(&self) -> bool
pub const fn ONBOARD_PEDAL_DIFFERENCE_FAULT(&self) -> bool
Bits: 12..13
Sourcepub const fn with_ONBOARD_PEDAL_DIFFERENCE_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_ONBOARD_PEDAL_DIFFERENCE_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 12..13
Sourcepub const fn with_ONBOARD_PEDAL_DIFFERENCE_FAULT(self, value: bool) -> Self
pub const fn with_ONBOARD_PEDAL_DIFFERENCE_FAULT(self, value: bool) -> Self
Bits: 12..13
Sourcepub const fn set_ONBOARD_PEDAL_DIFFERENCE_FAULT(&mut self, value: bool)
pub const fn set_ONBOARD_PEDAL_DIFFERENCE_FAULT(&mut self, value: bool)
Bits: 12..13
Sourcepub const fn set_ONBOARD_PEDAL_DIFFERENCE_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_ONBOARD_PEDAL_DIFFERENCE_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 12..13
Sourcepub const fn RTDS_FAULT(&self) -> bool
pub const fn RTDS_FAULT(&self) -> bool
Bits: 13..14
Sourcepub const fn with_RTDS_FAULT_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_RTDS_FAULT_checked(self, value: bool) -> Result<Self, ()>
Bits: 13..14
Sourcepub const fn with_RTDS_FAULT(self, value: bool) -> Self
pub const fn with_RTDS_FAULT(self, value: bool) -> Self
Bits: 13..14
Sourcepub const fn set_RTDS_FAULT(&mut self, value: bool)
pub const fn set_RTDS_FAULT(&mut self, value: bool)
Bits: 13..14
Sourcepub const fn LV_LOW_VOLTAGE_FAULT(&self) -> bool
pub const fn LV_LOW_VOLTAGE_FAULT(&self) -> bool
Bits: 14..15
Sourcepub const fn with_LV_LOW_VOLTAGE_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_LV_LOW_VOLTAGE_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
Bits: 14..15
Sourcepub const fn with_LV_LOW_VOLTAGE_FAULT(self, value: bool) -> Self
pub const fn with_LV_LOW_VOLTAGE_FAULT(self, value: bool) -> Self
Bits: 14..15
Sourcepub const fn set_LV_LOW_VOLTAGE_FAULT(&mut self, value: bool)
pub const fn set_LV_LOW_VOLTAGE_FAULT(&mut self, value: bool)
Bits: 14..15
Sourcepub const fn set_LV_LOW_VOLTAGE_FAULT_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_LV_LOW_VOLTAGE_FAULT_checked( &mut self, value: bool, ) -> Result<(), ()>
Bits: 14..15
Sourcepub const fn PRECHARGE_FLOATING_FAULT(&self) -> bool
pub const fn PRECHARGE_FLOATING_FAULT(&self) -> bool
If TS Volts is stuck under the Batt Volts Threshold
Bits: 15..16
Sourcepub const fn with_PRECHARGE_FLOATING_FAULT_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_PRECHARGE_FLOATING_FAULT_checked( self, value: bool, ) -> Result<Self, ()>
If TS Volts is stuck under the Batt Volts Threshold
Bits: 15..16
Sourcepub const fn with_PRECHARGE_FLOATING_FAULT(self, value: bool) -> Self
pub const fn with_PRECHARGE_FLOATING_FAULT(self, value: bool) -> Self
If TS Volts is stuck under the Batt Volts Threshold
Bits: 15..16
Sourcepub const fn set_PRECHARGE_FLOATING_FAULT(&mut self, value: bool)
pub const fn set_PRECHARGE_FLOATING_FAULT(&mut self, value: bool)
If TS Volts is stuck under the Batt Volts Threshold
Bits: 15..16