pub struct ImdGeneralInformation(/* private fields */);Implementations
Sourceimpl ImdGeneralInformation
impl ImdGeneralInformation
Sourcepub const fn R_iso_corrected(&self) -> u16
pub const fn R_iso_corrected(&self) -> u16
0…40500: corrected isolation value
Units: kΩ
Bits: 0..16
Sourcepub const fn with_R_iso_corrected_checked(self, value: u16) -> Result<Self, ()>
pub const fn with_R_iso_corrected_checked(self, value: u16) -> Result<Self, ()>
0…40500: corrected isolation value
Units: kΩ
Bits: 0..16
Sourcepub const fn with_R_iso_corrected(self, value: u16) -> Self
pub const fn with_R_iso_corrected(self, value: u16) -> Self
0…40500: corrected isolation value
Units: kΩ
Bits: 0..16
Sourcepub const fn set_R_iso_corrected(&mut self, value: u16)
pub const fn set_R_iso_corrected(&mut self, value: u16)
0…40500: corrected isolation value
Units: kΩ
Bits: 0..16
Sourcepub const fn set_R_iso_corrected_checked(
&mut self,
value: u16,
) -> Result<(), ()>
pub const fn set_R_iso_corrected_checked( &mut self, value: u16, ) -> Result<(), ()>
0…40500: corrected isolation value
Units: kΩ
Bits: 0..16
Sourcepub const fn R_iso_status(&self) -> u8
pub const fn R_iso_status(&self) -> u8
ISO Status
0xFC: estimated isolation value during startup 0xFD: first measured isolation value during startup 0xFE: Isolation value in normal operation
Bits: 16..24
Sourcepub const fn with_R_iso_status_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_R_iso_status_checked(self, value: u8) -> Result<Self, ()>
ISO Status
0xFC: estimated isolation value during startup 0xFD: first measured isolation value during startup 0xFE: Isolation value in normal operation
Bits: 16..24
Sourcepub const fn with_R_iso_status(self, value: u8) -> Self
pub const fn with_R_iso_status(self, value: u8) -> Self
ISO Status
0xFC: estimated isolation value during startup 0xFD: first measured isolation value during startup 0xFE: Isolation value in normal operation
Bits: 16..24
Sourcepub const fn set_R_iso_status(&mut self, value: u8)
pub const fn set_R_iso_status(&mut self, value: u8)
ISO Status
0xFC: estimated isolation value during startup 0xFD: first measured isolation value during startup 0xFE: Isolation value in normal operation
Bits: 16..24
Sourcepub const fn set_R_iso_status_checked(&mut self, value: u8) -> Result<(), ()>
pub const fn set_R_iso_status_checked(&mut self, value: u8) -> Result<(), ()>
ISO Status
0xFC: estimated isolation value during startup 0xFD: first measured isolation value during startup 0xFE: Isolation value in normal operation
Bits: 16..24
Sourcepub const fn Iso_measurement_counter(&self) -> u8
pub const fn Iso_measurement_counter(&self) -> u8
0…255 Counter will be incremented with each new measured isolation resistance value
Bits: 24..32
Sourcepub const fn with_Iso_measurement_counter_checked(
self,
value: u8,
) -> Result<Self, ()>
pub const fn with_Iso_measurement_counter_checked( self, value: u8, ) -> Result<Self, ()>
0…255 Counter will be incremented with each new measured isolation resistance value
Bits: 24..32
Sourcepub const fn with_Iso_measurement_counter(self, value: u8) -> Self
pub const fn with_Iso_measurement_counter(self, value: u8) -> Self
0…255 Counter will be incremented with each new measured isolation resistance value
Bits: 24..32
Sourcepub const fn set_Iso_measurement_counter(&mut self, value: u8)
pub const fn set_Iso_measurement_counter(&mut self, value: u8)
0…255 Counter will be incremented with each new measured isolation resistance value
Bits: 24..32
Sourcepub const fn set_Iso_measurement_counter_checked(
&mut self,
value: u8,
) -> Result<(), ()>
pub const fn set_Iso_measurement_counter_checked( &mut self, value: u8, ) -> Result<(), ()>
0…255 Counter will be incremented with each new measured isolation resistance value
Bits: 24..32
Sourcepub const fn device_error(&self) -> bool
pub const fn device_error(&self) -> bool
Device error active
Bits: 32..33
Sourcepub const fn with_device_error_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_device_error_checked(self, value: bool) -> Result<Self, ()>
Device error active
Bits: 32..33
Sourcepub const fn with_device_error(self, value: bool) -> Self
pub const fn with_device_error(self, value: bool) -> Self
Device error active
Bits: 32..33
Sourcepub const fn set_device_error(&mut self, value: bool)
pub const fn set_device_error(&mut self, value: bool)
Device error active
Bits: 32..33
Sourcepub const fn set_device_error_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_device_error_checked(&mut self, value: bool) -> Result<(), ()>
Device error active
Bits: 32..33
Sourcepub const fn HV_pos_conn_fail(&self) -> bool
pub const fn HV_pos_conn_fail(&self) -> bool
HV positive connection failure
Bits: 33..34
Sourcepub const fn with_HV_pos_conn_fail_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_HV_pos_conn_fail_checked( self, value: bool, ) -> Result<Self, ()>
HV positive connection failure
Bits: 33..34
Sourcepub const fn with_HV_pos_conn_fail(self, value: bool) -> Self
pub const fn with_HV_pos_conn_fail(self, value: bool) -> Self
HV positive connection failure
Bits: 33..34
Sourcepub const fn set_HV_pos_conn_fail(&mut self, value: bool)
pub const fn set_HV_pos_conn_fail(&mut self, value: bool)
HV positive connection failure
Bits: 33..34
Sourcepub const fn set_HV_pos_conn_fail_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_HV_pos_conn_fail_checked( &mut self, value: bool, ) -> Result<(), ()>
HV positive connection failure
Bits: 33..34
Sourcepub const fn HV_neg_conn_fail(&self) -> bool
pub const fn HV_neg_conn_fail(&self) -> bool
HV negative connection failure
Bits: 34..35
Sourcepub const fn with_HV_neg_conn_fail_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_HV_neg_conn_fail_checked( self, value: bool, ) -> Result<Self, ()>
HV negative connection failure
Bits: 34..35
Sourcepub const fn with_HV_neg_conn_fail(self, value: bool) -> Self
pub const fn with_HV_neg_conn_fail(self, value: bool) -> Self
HV negative connection failure
Bits: 34..35
Sourcepub const fn set_HV_neg_conn_fail(&mut self, value: bool)
pub const fn set_HV_neg_conn_fail(&mut self, value: bool)
HV negative connection failure
Bits: 34..35
Sourcepub const fn set_HV_neg_conn_fail_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_HV_neg_conn_fail_checked( &mut self, value: bool, ) -> Result<(), ()>
HV negative connection failure
Bits: 34..35
Sourcepub const fn Earth_conn_fail(&self) -> bool
pub const fn Earth_conn_fail(&self) -> bool
Earth connection failure
Bits: 35..36
Sourcepub const fn with_Earth_conn_fail_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_Earth_conn_fail_checked(self, value: bool) -> Result<Self, ()>
Earth connection failure
Bits: 35..36
Sourcepub const fn with_Earth_conn_fail(self, value: bool) -> Self
pub const fn with_Earth_conn_fail(self, value: bool) -> Self
Earth connection failure
Bits: 35..36
Sourcepub const fn set_Earth_conn_fail(&mut self, value: bool)
pub const fn set_Earth_conn_fail(&mut self, value: bool)
Earth connection failure
Bits: 35..36
Sourcepub const fn set_Earth_conn_fail_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_Earth_conn_fail_checked( &mut self, value: bool, ) -> Result<(), ()>
Earth connection failure
Bits: 35..36
Sourcepub const fn with_Iso_alarm_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_Iso_alarm_checked(self, value: bool) -> Result<Self, ()>
iso value below threshold error
Bits: 36..37
Sourcepub const fn with_Iso_alarm(self, value: bool) -> Self
pub const fn with_Iso_alarm(self, value: bool) -> Self
iso value below threshold error
Bits: 36..37
Sourcepub const fn set_Iso_alarm(&mut self, value: bool)
pub const fn set_Iso_alarm(&mut self, value: bool)
iso value below threshold error
Bits: 36..37
Sourcepub const fn set_Iso_alarm_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_Iso_alarm_checked(&mut self, value: bool) -> Result<(), ()>
iso value below threshold error
Bits: 36..37
Sourcepub const fn iso_warning(&self) -> bool
pub const fn iso_warning(&self) -> bool
(Iso value below threshold warning)
Bits: 37..38
Sourcepub const fn with_iso_warning_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_iso_warning_checked(self, value: bool) -> Result<Self, ()>
(Iso value below threshold warning)
Bits: 37..38
Sourcepub const fn with_iso_warning(self, value: bool) -> Self
pub const fn with_iso_warning(self, value: bool) -> Self
(Iso value below threshold warning)
Bits: 37..38
Sourcepub const fn set_iso_warning(&mut self, value: bool)
pub const fn set_iso_warning(&mut self, value: bool)
(Iso value below threshold warning)
Bits: 37..38
Sourcepub const fn set_iso_warning_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_iso_warning_checked(&mut self, value: bool) -> Result<(), ()>
(Iso value below threshold warning)
Bits: 37..38
Sourcepub const fn iso_outdated(&self) -> bool
pub const fn iso_outdated(&self) -> bool
Unbalance value below threshold
Bits: 38..39
Sourcepub const fn with_iso_outdated_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_iso_outdated_checked(self, value: bool) -> Result<Self, ()>
Unbalance value below threshold
Bits: 38..39
Sourcepub const fn with_iso_outdated(self, value: bool) -> Self
pub const fn with_iso_outdated(self, value: bool) -> Self
Unbalance value below threshold
Bits: 38..39
Sourcepub const fn set_iso_outdated(&mut self, value: bool)
pub const fn set_iso_outdated(&mut self, value: bool)
Unbalance value below threshold
Bits: 38..39
Sourcepub const fn set_iso_outdated_checked(&mut self, value: bool) -> Result<(), ()>
pub const fn set_iso_outdated_checked(&mut self, value: bool) -> Result<(), ()>
Unbalance value below threshold
Bits: 38..39
Sourcepub const fn Unbalance_alarm(&self) -> bool
pub const fn Unbalance_alarm(&self) -> bool
Undervoltage alarm
Bits: 39..40
Sourcepub const fn with_Unbalance_alarm_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_Unbalance_alarm_checked(self, value: bool) -> Result<Self, ()>
Undervoltage alarm
Bits: 39..40
Sourcepub const fn with_Unbalance_alarm(self, value: bool) -> Self
pub const fn with_Unbalance_alarm(self, value: bool) -> Self
Undervoltage alarm
Bits: 39..40
Sourcepub const fn set_Unbalance_alarm(&mut self, value: bool)
pub const fn set_Unbalance_alarm(&mut self, value: bool)
Undervoltage alarm
Bits: 39..40
Sourcepub const fn set_Unbalance_alarm_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_Unbalance_alarm_checked( &mut self, value: bool, ) -> Result<(), ()>
Undervoltage alarm
Bits: 39..40
Sourcepub const fn Undervoltage_alarm(&self) -> bool
pub const fn Undervoltage_alarm(&self) -> bool
Undervoltage_Alarm
Bits: 40..41
Sourcepub const fn with_Undervoltage_alarm_checked(
self,
value: bool,
) -> Result<Self, ()>
pub const fn with_Undervoltage_alarm_checked( self, value: bool, ) -> Result<Self, ()>
Undervoltage_Alarm
Bits: 40..41
Sourcepub const fn with_Undervoltage_alarm(self, value: bool) -> Self
pub const fn with_Undervoltage_alarm(self, value: bool) -> Self
Undervoltage_Alarm
Bits: 40..41
Sourcepub const fn set_Undervoltage_alarm(&mut self, value: bool)
pub const fn set_Undervoltage_alarm(&mut self, value: bool)
Undervoltage_Alarm
Bits: 40..41
Sourcepub const fn set_Undervoltage_alarm_checked(
&mut self,
value: bool,
) -> Result<(), ()>
pub const fn set_Undervoltage_alarm_checked( &mut self, value: bool, ) -> Result<(), ()>
Undervoltage_Alarm
Bits: 40..41
Sourcepub const fn Unsafe_to_start(&self) -> bool
pub const fn Unsafe_to_start(&self) -> bool
Earthlift Open
Bits: 41..42
Sourcepub const fn with_Unsafe_to_start_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_Unsafe_to_start_checked(self, value: bool) -> Result<Self, ()>
Earthlift Open
Bits: 41..42
Sourcepub const fn with_Unsafe_to_start(self, value: bool) -> Self
pub const fn with_Unsafe_to_start(self, value: bool) -> Self
Earthlift Open
Bits: 41..42
Sourcepub const fn set_Unsafe_to_start(&mut self, value: bool)
pub const fn set_Unsafe_to_start(&mut self, value: bool)
Earthlift Open
Bits: 41..42