pub struct RtdsStateMessage(/* private fields */);Implementations
Sourceimpl RtdsStateMessage
impl RtdsStateMessage
Sourcepub const fn with_pin_state_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_pin_state_checked(self, value: u8) -> Result<Self, ()>
The state of the RTDS Pin.
Bits: 0..8
Sourcepub const fn with_pin_state(self, value: u8) -> Self
pub const fn with_pin_state(self, value: u8) -> Self
The state of the RTDS Pin.
Bits: 0..8
Sourcepub const fn set_pin_state(&mut self, value: u8)
pub const fn set_pin_state(&mut self, value: u8)
The state of the RTDS Pin.
Bits: 0..8
Sourcepub const fn set_pin_state_checked(&mut self, value: u8) -> Result<(), ()>
pub const fn set_pin_state_checked(&mut self, value: u8) -> Result<(), ()>
The state of the RTDS Pin.
Bits: 0..8
Sourcepub const fn sounding_state(&self) -> u8
pub const fn sounding_state(&self) -> u8
Whether or not the RTDS system is attempting to sound the main continuous RTDS sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the RTDS Timer is active, indicating that the car is actively trying to make the sound.
Bits: 8..16
Sourcepub const fn with_sounding_state_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_sounding_state_checked(self, value: u8) -> Result<Self, ()>
Whether or not the RTDS system is attempting to sound the main continuous RTDS sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the RTDS Timer is active, indicating that the car is actively trying to make the sound.
Bits: 8..16
Sourcepub const fn with_sounding_state(self, value: u8) -> Self
pub const fn with_sounding_state(self, value: u8) -> Self
Whether or not the RTDS system is attempting to sound the main continuous RTDS sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the RTDS Timer is active, indicating that the car is actively trying to make the sound.
Bits: 8..16
Sourcepub const fn set_sounding_state(&mut self, value: u8)
pub const fn set_sounding_state(&mut self, value: u8)
Whether or not the RTDS system is attempting to sound the main continuous RTDS sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the RTDS Timer is active, indicating that the car is actively trying to make the sound.
Bits: 8..16
Sourcepub const fn set_sounding_state_checked(&mut self, value: u8) -> Result<(), ()>
pub const fn set_sounding_state_checked(&mut self, value: u8) -> Result<(), ()>
Whether or not the RTDS system is attempting to sound the main continuous RTDS sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the RTDS Timer is active, indicating that the car is actively trying to make the sound.
Bits: 8..16
Sourcepub const fn reverse_state(&self) -> u8
pub const fn reverse_state(&self) -> u8
Whether or not the RTDS system is attempting to sound the reverse sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the Reverse Sound Timer is active, indicating whether or not the RTDS system is trying to make the beeping sound.
Bits: 16..24
Sourcepub const fn with_reverse_state_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_reverse_state_checked(self, value: u8) -> Result<Self, ()>
Whether or not the RTDS system is attempting to sound the reverse sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the Reverse Sound Timer is active, indicating whether or not the RTDS system is trying to make the beeping sound.
Bits: 16..24
Sourcepub const fn with_reverse_state(self, value: u8) -> Self
pub const fn with_reverse_state(self, value: u8) -> Self
Whether or not the RTDS system is attempting to sound the reverse sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the Reverse Sound Timer is active, indicating whether or not the RTDS system is trying to make the beeping sound.
Bits: 16..24
Sourcepub const fn set_reverse_state(&mut self, value: u8)
pub const fn set_reverse_state(&mut self, value: u8)
Whether or not the RTDS system is attempting to sound the reverse sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the Reverse Sound Timer is active, indicating whether or not the RTDS system is trying to make the beeping sound.
Bits: 16..24
Sourcepub const fn set_reverse_state_checked(&mut self, value: u8) -> Result<(), ()>
pub const fn set_reverse_state_checked(&mut self, value: u8) -> Result<(), ()>
Whether or not the RTDS system is attempting to sound the reverse sound.
This is not the same as the pure RTDS pin state. This refers to whether or not the Reverse Sound Timer is active, indicating whether or not the RTDS system is trying to make the beeping sound.
Bits: 16..24
Sourcepub const fn with_error_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_error_checked(self, value: u8) -> Result<Self, ()>
Indicates if an error occured during reading.
Bits: 24..32
Sourcepub const fn with_error(self, value: u8) -> Self
pub const fn with_error(self, value: u8) -> Self
Indicates if an error occured during reading.
Bits: 24..32